# NOTE: this class has been translated from Java.
# Do not modify this file, changes will be overwritten.

#package orbitgt.mapping3d.sdk.viewer;

from .....com.orbitgis.tool.Strings import Strings
from .....orbitgt.mapping3d.sdk.viewer.AList import AList

#
# Class Coordinate defines a spatial coordinate. It has a coordinate reference system (CRS) and can be 2D or 3D.
#

class Coordinate:
    # The type of objects in this class */
    TYPE: str = "C"

    # The EPSG CRS code, like "4326" for example */
    #public String crs
    # The X value */
    #public double x
    # The Y value */
    #public double y
    # The Z value */
    #public double z
    # Does the coordinate have a valid Z value? */
    #public boolean is3D

    #
    # Create a new coordinate.
    # @param crs the EPSG CRS code, like "4326" for example.
    # @param x the X value.
    # @param y the Y value.
    # @param z the Z value.
    # @param is3D does the coordinate have a valid Z value?
    #
    def __init__(self,crs: str,x: float,y: float,z: float,is3D: bool):
        self.crs = crs
        self.x = x
        self.y = y
        self.z = z
        self.is3D = is3D

    #
    # Create a new 2D coordinate.
    # @param crs the EPSG CRS code, like "4326" for example.
    # @param x the X value.
    # @param y the Y value.
    # @return the coordinate.
    #
    def fromXY(crs: str,x: float,y: float) -> 'Coordinate':
        return Coordinate(crs,x,y,0.0,False)

    #
    # Create a new 3D coordinate.
    # @param crs the EPSG CRS code, like "4326" for example.
    # @param x the X value.
    # @param y the Y value.
    # @param z the Z value.
    # @return the coordinate.
    #
    def fromXYZ(crs: str,x: float,y: float,z: float) -> 'Coordinate':
        return Coordinate(crs,x,y,z,True)

    #
    # Convert to a WKT string.
    # @return a WKT string.
    #
    def asWKT(self) -> str:
        if (self.is3D): return "Point Z ("+Strings.toString(self.x)+" "+Strings.toString(self.y)+" "+Strings.toString(self.z)+")"
        else: return "Point ("+Strings.toString(self.x)+" "+Strings.toString(self.y)+")"

    # python remove begin
    #     /**
    #      * Join a list of coordinates into a string.
    #      * @param coordinates the list of coordinates.
    #      * @return the string.
    #      */
    #     static public String join(AList<Coordinate> coordinates)
    #     {
    # 	    if (coordinates==null) return "";
    #     	StringBuilder clist = new StringBuilder();
    #     	for(int i=0; i<coordinates.size(); i++)
    #     	{
    #     		if (i>0) clist.append(",");
    #     		clist.append(coordinates.get(i));
    #     	}
    #     	return clist.toString();
    #     }
    # python remove end

    #
    # Convert the object to a string.
    # @return the string form of the object.
    #
    def toString(self) -> str:
        if (self.is3D): return "[Coordinate:crs="+self.crs+",x="+self.x+",y="+self.y+",z="+self.z+"]"
        else: return "[Coordinate:crs="+self.crs+",x="+self.x+",y="+self.y+"]"
